@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.75'; # Closer now... 
+our $VERSION = '0.76'; # But I need a GP module!
 
 # Preloaded methods go here.
 
@@ -66,7 +66,7 @@ web.
 =begin html
 
 <p>The project is hosted at
-<a href='http://opeal.sourceforge.net'>Sourceforge </a>. Latest aditions, and
+<a href='http://opeal.sourceforge.net'>Sourceforge</a>. Latest aditions, and
 nightly updates, can be downloaded from there before they are uploaded
 to CPAN. That page also hosts the mailing list, as well as bug
 reports, news, updates, work in progress, lots of stuff.</p>
@@ -84,7 +84,7 @@ forum</a> (where I usually hang around) or from <a
 href='mailto:opeal-help-request@lists.sourceforge.net'>the mailing
 list</a> (information at <a
 href='https://lists.sourceforge.net/lists/listinfo/opeal-help'>its web
-site</a>)</p> 
+site</a>).</p> 
 
 <p>It might be also helpful for you to check out <a
 href='http://arxiv.org/abs/0908.0516'>Still doing evolutionary
@@ -148,7 +148,7 @@ research, I would be very grateful if you quoted papers such as these
 <p>Some information on this paper and instructions for downloading the code used in it can
 be found in <a
 href='http://nohnes.wordpress.com/2008/09/21/paper-on-performance-of-asynchronous-distributed-evolutionary-algorithms-available-online/'>our
-group blog</a></p> 
+group blog</a>.</p> 
 
 =end html
 
@@ -175,7 +175,7 @@ href='http://twitter.com/jjmerelo'>twitter.com/jjmerelo</a>. There have
 also been some contributions from Javi Garca, fjgc (at) decsai.ugr.es
 and Pedro Castillo, pedro (at) geneura.ugr.es. Patient users that have
 submitted bugs include <a
-href='http://barbacana.net'>jamarier</a> and Mike Gajewski. <a href='http://alexm.org'>Alex Muntada</a>,
+href='http://barbacana.net'>jamarier</a>, <a href='http://leandrohermida.com'>Leandro Hermida</a>, Jrme Qulin  and Mike Gajewski. <a href='http://alexm.org'>Alex Muntada</a>,
 from the <a href='http://barcelona.pm.org/'>Barcelona Perl
 Mongers</a>, helped me solve a problem with the Makefile.PL. Bug reports (and patches), requests and any kind 
 of comment are welcome.
@@ -236,9 +236,9 @@ L<AI::Genetic::Pro>.
 This file is released under the GPL. See the LICENSE file included in this distribution,
 or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/12/07 12:04:51 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.13 2010/12/07 12:04:51 jmerelo Exp $ 
+  CVS Info: $Date: 2011/02/13 18:01:04 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.16 2011/02/13 18:01:04 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.13 $
+  $Revision: 3.16 $
 
 =cut
