@@ -2,14 +2,15 @@ use strict;
 use warnings;
 
 =head1 NAME
-Algorithm::Evolutionary::Op::Breeder_Diverser - Like Breeder, only it tries to cross only individuals that are different 
 
+Algorithm::Evolutionary::Op::Breeder_Diverser - Even more customizable single generation for an evolutionary algorithm.
+                 
 =head1 SYNOPSIS
 
     use Algorithm::Evolutionary qw( Individual::BitString 
-      Op::Mutation Op::Crossover
-      Op::RouletteWheel
-      Op::Breeder_Diverser);
+    Op::Mutation Op::Crossover
+    Op::RouletteWheel
+    Op::Breeder_Diverser);
 
     use Algorithm::Evolutionary::Utils qw(average);
 
@@ -45,10 +46,7 @@ L<Algorithm::Evolutionary::Op::Base>
 Breeder part of the evolutionary algorithm; takes a population and
 returns another created from the first. Different from
 L<Algorithm::Evolutionary::Op::Breeder>: tries to avoid crossover
-among the same individuals and also re-creating an individual already
-in the pool. In that sense it "diverses", tries to diversify the
-population. In general, it works better in environments where high
-diversity is needed (like, for instance, in L<Algorithm::MasterMind>.
+among the same individuals. 
 
 =head1 METHODS
 
@@ -58,7 +56,7 @@ package Algorithm::Evolutionary::Op::Breeder_Diverser;
 
 use lib qw(../../..);
 
-our ($VERSION) = ( '$Revision: 1.7 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 1.1 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use Carp;
 
@@ -94,9 +92,6 @@ been evaluated first; checks that it receives a
 ref-to-array as input, croaks if it does not. Returns a sorted,
 culled, evaluated population for next generation.
 
-It is valid only for string-denominated chromosomes. Checks that the
-offspring is different from parents before inserting it. 
-
 =cut
 
 sub apply ($) {
@@ -115,37 +110,34 @@ sub apply ($) {
     for ( @ops ) {
 	push( @rates, $_->{rate});
     }
-    my $op_wheel = new Algorithm::Evolutionary::Wheel @rates;
+    my $opWheel = new Algorithm::Evolutionary::Wheel @rates;
 
     my @new_population;
-    my $i = 0;
-    while ( @new_population < $output_size ) {
-      my @offspring;
-      my $selected_op = $ops[ $op_wheel->spin()];
-      my $chosen = $genitors[ $i++ % @genitors]; #Chosen in turn
-      push( @offspring, $chosen->clone() );
-      if( $selected_op->{'_arity'} == 2 ) {
-	my $another_one;
-	do {
-	  $another_one = $genitors[ rand( @genitors )];
-	} until ( $another_one->{'_str'} ne  $chosen->{'_str'} );
-	push( @offspring, $another_one );
-      } elsif ( $selected_op->{'_arity'} > 2 ) {
-	for ( my $j = 1; $j < $selected_op->arity(); $j ++ ) {
+    for ( my $i = 0; $i < $output_size; $i++ ) {
+	my @offspring;
+	my $selectedOp = $ops[ $opWheel->spin()];
+#	  print $selectedOp->asXML;
+	if ( $selectedOp->arity() == 1 ) {
 	  my $chosen = $genitors[ rand( @genitors )];
 	  push( @offspring, $chosen->clone() );
+	} elsif( $selectedOp->arity() == 2 ) {
+	  my $chosen = $genitors[ rand( @genitors )];
+	  push( @offspring, $chosen->clone() );
+	  my $another_one;
+	  do {
+	    $another_one = $genitors[ rand( @genitors )];
+	  } until ( $another_one->{'_str'} ne  $chosen->{'_str'} );
+	  push( @offspring, $another_one );
+	} else {
+	  for ( my $j = 0; $j < $selectedOp->arity(); $j ++ ) {
+	    my $chosen = $genitors[ rand( @genitors )];
+	    push( @offspring, $chosen->clone() );
+	  }
 	}
+	my $mutante = $selectedOp->apply( @offspring );
+#	print join(" - ", map( $_->{'_str'}, @offspring ) ), "=> ", $mutante->{'_str'}, "\n";
+	push( @new_population, $mutante );
       }
-      my $mutant = $selected_op->apply( @offspring );
-      my $equal;
-      for my $o (@offspring) {
-	$equal += $o->{'_str'} eq  $mutant->{'_str'};
-      }
-      if ( !$equal ) {
-	push( @new_population, $mutant );
-      } 
-
-    }
     return \@new_population;
 }
 
@@ -159,10 +151,6 @@ More or less in the same ballpark, alternatives to this one
 
 L<Algorithm::Evolutionary::Op::GeneralGeneration>
 
-=item * 
-
-L<Algorithm::Evolutionary::Op::Breeder>
-
 =back
 
 =head1 Copyright
@@ -170,10 +158,10 @@ L<Algorithm::Evolutionary::Op::Breeder>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2013/01/07 13:54:20 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Breeder_Diverser.pm,v 1.7 2013/01/07 13:54:20 jmerelo Exp $ 
+  CVS Info: $Date: 2010/12/22 14:23:18 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Breeder_Diverser.pm,v 1.1 2010/12/22 14:23:18 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.7 $
+  $Revision: 1.1 $
 
 =cut
 
